# ur_gadget
Useful gadgets for your python projects

<img src="https://img.shields.io/pypi/pyversions/ur_gadget?logoColor=brown&style=plastic" alt= "Version"/>
<img src="https://img.shields.io/pypi/dm/ur_gadget" alt="Download Badge"/>
<img src="https://img.shields.io/github/last-commit/thinh-vu/ur_gadget" alt="Commit Badge"/>
<img src="https://img.shields.io/github/license/thinh-vu/ur_gadget?color=red" alt="License Badge"/>
</div>

# II. REFERENCES
## 2.1. How to use this package?
- You can install the latest `ur_gadget` crawler version from source with the following command:
`pip install git+https://github.com/thinh-vu/ur_gadget.git@main`
- Install the stable version: `pip install ur_gadget`
_(*) You might need to insert a `!` before your command when running terminal commands on Google Colab._

- To start using functions, you need to import them: `from ur_gadget import *`


# III. APENDICES
- Explore User Agents for API requests by Operating System: [here](https://developers.whatismybrowser.com/useragents/explore/operating_system_name/)

# IV. 🙋‍♂️ CONTACT INFORMATION
You can contact me at one of my social network profiles:

<div id="badges" align="center">
  <a href="https://www.linkedin.com/in/thinh-vu">
    <img src="https://img.shields.io/badge/LinkedIn-blue?style=for-the-badge&logo=linkedin&logoColor=white" alt="LinkedIn Badge"/>
  </a>
  <a href="https://www.messenger.com/t/mr.thinh.ueh">
    <img src="https://img.shields.io/badge/Messenger-00B2FF?style=for-the-badge&logo=messenger&logoColor=white" alt="Messenger Badge"/>
  <a href="https://www.youtube.com/channel/UCYgG-bmk92OhYsP20TS0MbQ">
    <img src="https://img.shields.io/badge/YouTube-red?style=for-the-badge&logo=youtube&logoColor=white" alt="Youtube Badge"/>
  </a>
  </a>
    <a href="https://github.com/thinh-vu">
    <img src="https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white" alt="Github Badge"/>
  </a>
</div>

---

If you want to support my open-source projects, you can "buy me a coffee" via [Patreon](https://patreon.com/thinhvu?utm_medium=clipboard_copy&utm_source=copyLink&utm_campaign=creatorshare_creator) or Momo e-wallet (VN). Your support will help to maintain my blog hosting fee & to develop high-quality content.

<details>
<summary> Momo QR </summary>

![momo-qr](https://github.com/thinh-vu/vnstock/blob/main/src/momo-qr-thinhvu.jpeg?raw=true)

</details>